" 
" Simple Virtual Machine - A versatile and robust architecture to
" easily write applications.
" Copyright (C) 2021  Julien BRUGUIER
" 
" This program is free software: you can redistribute it and/or modify
" it under the terms of the GNU General Public License as published by
" the Free Software Foundation, either version 3 of the License, or
" (at your option) any later version.
" 
" This program is distributed in the hope that it will be useful,
" but WITHOUT ANY WARRANTY; without even the implied warranty of
" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
" GNU General Public License for more details.
" 
" You should have received a copy of the GNU General Public License
" along with this program.  If not, see <http://www.gnu.org/licenses/>.
" 

syntax clear

syntax match SectionHeader "^[^:]*:" contains=SectionKey,SectionOption

syntax keyword SectionKey attach contained
syntax keyword SectionKey author contained
syntax keyword SectionKey changelog contained
syntax keyword SectionKey checks contained
syntax keyword SectionKey code contained
syntax keyword SectionKey compile contained
syntax keyword SectionKey constant contained
syntax keyword SectionKey copy contained
syntax keyword SectionKey compare contained
syntax keyword SectionKey create contained
syntax keyword SectionKey current contained
syntax keyword SectionKey date contained
syntax keyword SectionKey delete contained
syntax keyword SectionKey description contained
syntax keyword SectionKey detach contained
syntax keyword SectionKey example contained
syntax keyword SectionKey finalisation contained
syntax keyword SectionKey help contained
syntax keyword SectionKey includes contained
syntax keyword SectionKey initialisation contained
syntax keyword SectionKey lang contained
syntax keyword SectionKey license contained
syntax keyword SectionKey link contained
syntax keyword SectionKey maintainer contained
syntax keyword SectionKey news contained
syntax keyword SectionKey notification contained
syntax keyword SectionKey patch contained
syntax keyword SectionKey print contained
syntax keyword SectionKey readme contained
syntax keyword SectionKey schedule contained
syntax keyword SectionKey seealso contained
syntax keyword SectionKey shell contained
syntax keyword SectionKey startup contained
syntax keyword SectionKey synopsis contained
syntax keyword SectionKey test contained
syntax keyword SectionKey title contained
syntax keyword SectionKey usage contained
syntax keyword SectionKey version contained

syntax keyword SectionOption default contained
syntax keyword SectionOption object contained
syntax keyword SectionOption string contained

syntax match SectionHeaderIdentifier "^\(comment\|file\)[^:]*:" contains=SectionKeyIdentifier
syntax keyword SectionKeyIdentifier comment contained
syntax keyword SectionKeyIdentifier file contained

syntax keyword PluginName PLUGIN

syntax keyword PluginPart USE
syntax keyword PluginPart DEFINE

syntax match InstructionHeader "^.*INSTRUCTION" contains=InstructionOption,PluginObject

syntax keyword PluginObject TYPE
syntax keyword PluginObject STRUCT
syntax keyword PluginObject INSTRUCTION contained
syntax keyword PluginObject FUNCTION
syntax keyword PluginObject INTERRUPTION
syntax keyword PluginObject SEQUENCER
syntax keyword PluginObject SCHEDULER
syntax keyword PluginObject OPTION
syntax keyword PluginObject ARGUMENT
syntax keyword PluginObject ARGUMENTS

syntax keyword InstructionOption SYSTEM contained
syntax keyword InstructionOption WAITING contained
syntax keyword InstructionOption OVERRIDE contained

syntax region SectionBody start="%{\n" end="\n%}" contains=SectionBodyEdge,SectionVariable,SectionMacro,SVMType,SVMFunction,SVMConstant keepend transparent

syntax match SectionBodyEdge "%{\n" contained
syntax match SectionBodyEdge "\n%}" contained

syntax match SectionBodyEdge "%{ \?%\?}"
syntax match SectionBodyEdge "%{\n%}"

syntax region SectionBody start="${\n" end="\n$}" contains=SectionBodyEdge,SectionVariable,SectionMacro,SVMType,SVMFunction,SVMConstant keepend transparent

syntax match SectionBodyEdge "${\n" contained
syntax match SectionBodyEdge "\n$}" contained

syntax match SectionBodyEdge "${ \?$\?}"
syntax match SectionBodyEdge "${\n$}"

syntax region SectionBody start=":{\n" end="\n:}" contains=SectionBodyEdge,SectionVariable,SectionMacro,SVMType,SVMFunction,SVMConstant keepend transparent

syntax match SectionBodyEdge ":{\n" contained
syntax match SectionBodyEdge "\n:}" contained

syntax match SectionBodyEdge ":{ \?:\?}"
syntax match SectionBodyEdge ":{\n:}"

syntax keyword SectionVariable svm contained
syntax keyword SectionVariable argc contained
syntax keyword SectionVariable argv contained
syntax keyword SectionVariable handler contained
syntax keyword SectionVariable object contained
syntax keyword SectionVariable handler_left contained
syntax keyword SectionVariable object_left contained
syntax keyword SectionVariable handler_right contained
syntax keyword SectionVariable object_right contained
syntax keyword SectionVariable process contained
syntax keyword SectionVariable kernel contained
syntax keyword SectionVariable state contained
syntax keyword SectionVariable parameter contained
syntax keyword SectionVariable value contained
syntax keyword SectionVariable string contained
syntax keyword SectionVariable type contained
syntax keyword SectionVariable copy contained

syntax keyword SectionMacro ARGV_VALUE contained
syntax keyword SectionMacro ARGV_PLUGIN contained
syntax keyword SectionMacro ARGV_MARKER contained
syntax keyword SectionMacro ARGV_KEYWORD contained
syntax keyword SectionMacro ARGV_STRUCT contained
syntax keyword SectionMacro ARGV_VARIABLE contained
syntax keyword SectionMacro NEW_VALUE contained
syntax keyword SectionMacro NEW_PLUGIN contained
syntax keyword SectionMacro NEW_STRUCT contained
syntax keyword SectionMacro NEW_STRING contained
syntax keyword SectionMacro RAW_STRING contained
syntax keyword SectionMacro NEW_NULL_VALUE contained
syntax keyword SectionMacro NEW_NULL_PLUGIN contained
syntax keyword SectionMacro NEW_NULL_STRUCT contained
syntax keyword SectionMacro ERROR_INTERNAL contained
syntax keyword SectionMacro ERROR_EXTERNAL contained
syntax keyword SectionMacro CONST_PEP contained
syntax keyword SectionMacro CURRENT contained
syntax keyword SectionMacro RETURN contained
syntax keyword SectionMacro VARIABLE_GLOBAL contained
syntax keyword SectionMacro VARIABLE_LOCAL contained
syntax keyword SectionMacro VARIABLE_DELETE contained

syntax region SectionBodyShort start=+"+ end=+"+ skip=+\\"+ keepend

syntax match Comment "#.*"

highlight link SectionKey Type
highlight link SectionKeyIdentifier Type
highlight link SectionOption Function
highlight link PluginName Keyword
highlight link PluginObject Keyword
highlight link PluginPart Todo
highlight link InstructionOption Special
highlight link SectionBodyEdge Constant
highlight link SectionBodyShort Constant
highlight link SectionVariable Tag
highlight link SectionMacro Tag
highlight link SVMType Type
highlight link SVMFunction Function
highlight link SVMConstant Constant

syntax keyword SVMFunction svm_accesscontrol_new contained
syntax keyword SVMFunction svm_kernel_get_accesscontrol contained
syntax keyword SVMFunction svm_code_label_get_address contained
syntax keyword SVMFunction svm_code_label_get_address__raw contained
syntax keyword SVMFunction svm_code_label_get_address__string contained
syntax keyword SVMFunction svm_value_pointer_get_address contained
syntax keyword SVMFunction svm_value_symbol_get_address contained
syntax keyword SVMFunction svm_accesscontrol_has_instructions contained
syntax keyword SVMFunction svm_accesscontrol_has_memory contained
syntax keyword SVMFunction svm_code_instruction_is_system contained
syntax keyword SVMFunction svm_code_instruction_is_waiting contained
syntax keyword SVMFunction svm_code_label_has_address contained
syntax keyword SVMFunction svm_code_label_has_address__raw contained
syntax keyword SVMFunction svm_code_label_has_address__string contained
syntax keyword SVMFunction svm_code_symbol_has_address contained
syntax keyword SVMFunction svm_code_symbol_has_address__raw contained
syntax keyword SVMFunction svm_code_symbol_has_address__string contained
syntax keyword SVMFunction svm_event_address_has_struct contained
syntax keyword SVMFunction svm_event_queue_check contained
syntax keyword SVMFunction svm_event_queue_check__raw contained
syntax keyword SVMFunction svm_event_queue_pull contained
syntax keyword SVMFunction svm_kernel_has_lastreturnisshutdown contained
syntax keyword SVMFunction svm_kernel_has_protectedmode contained
syntax keyword SVMFunction svm_kernel_has_transmitinterruption contained
syntax keyword SVMFunction svm_kernel_is_runnable contained
syntax keyword SVMFunction svm_kernel_is_terminated contained
syntax keyword SVMFunction svm_machine_mode_is_debug contained
syntax keyword SVMFunction svm_machine_mode_is_performance contained
syntax keyword SVMFunction svm_memory_address_is_defined contained
syntax keyword SVMFunction svm_memory_address_is_initialised contained
syntax keyword SVMFunction svm_memory_address_is_writable contained
syntax keyword SVMFunction svm_memory_has_alias contained
syntax keyword SVMFunction svm_memory_has_alias__raw contained
syntax keyword SVMFunction svm_memory_has_alias__string contained
syntax keyword SVMFunction svm_memory_pointer_has_alias contained
syntax keyword SVMFunction svm_parameter_type_is_keyword contained
syntax keyword SVMFunction svm_parameter_type_is_marker contained
syntax keyword SVMFunction svm_parameter_type_is_structure contained
syntax keyword SVMFunction svm_parameter_type_is_value contained
syntax keyword SVMFunction svm_parameter_type_is_variable contained
syntax keyword SVMFunction svm_plugin_has_argument contained
syntax keyword SVMFunction svm_plugin_has_arguments contained
syntax keyword SVMFunction svm_plugin_has_function contained
syntax keyword SVMFunction svm_plugin_has_instruction contained
syntax keyword SVMFunction svm_plugin_has_interruption contained
syntax keyword SVMFunction svm_plugin_has_option contained
syntax keyword SVMFunction svm_plugin_has_scheduler contained
syntax keyword SVMFunction svm_plugin_has_sequencer contained
syntax keyword SVMFunction svm_plugin_has_structure contained
syntax keyword SVMFunction svm_plugin_has_type contained
syntax keyword SVMFunction svm_process_has_scheduler contained
syntax keyword SVMFunction svm_process_kernel_attach contained
syntax keyword SVMFunction svm_process_kernel_detach contained
syntax keyword SVMFunction svm_process_ownership_check contained
syntax keyword SVMFunction svm_process_ownership_get_local contained
syntax keyword SVMFunction svm_processor_has_flag contained
syntax keyword SVMFunction svm_processor_has_flag__raw contained
syntax keyword SVMFunction svm_processor_has_flag__string contained
syntax keyword SVMFunction svm_processor_instructionoverride_has_global contained
syntax keyword SVMFunction svm_processor_instructionoverride_has_local contained
syntax keyword SVMFunction svm_processor_interruptionhandler_has contained
syntax keyword SVMFunction svm_processor_is_hardwareinterrupted contained
syntax keyword SVMFunction svm_scheduler_process_attach contained
syntax keyword SVMFunction svm_scheduler_process_attach__raw contained
syntax keyword SVMFunction svm_scheduler_process_detach contained
syntax keyword SVMFunction svm_scheduler_process_detach__raw contained
syntax keyword SVMFunction svm_string_is_equal contained
syntax keyword SVMFunction svm_string_is_equal__buffer contained
syntax keyword SVMFunction svm_string_is_equal__raw contained
syntax keyword SVMFunction svm_type_equal_external contained
syntax keyword SVMFunction svm_type_equal_internal contained
syntax keyword SVMFunction svm_type_is_external contained
syntax keyword SVMFunction svm_type_is_internal contained
syntax keyword SVMFunction svm_value_boolean_get contained
syntax keyword SVMFunction svm_value_interruption_is_external contained
syntax keyword SVMFunction svm_value_interruption_is_internal contained
syntax keyword SVMFunction svm_value_is_equal contained
syntax keyword SVMFunction svm_value_state_is_constant contained
syntax keyword SVMFunction svm_value_state_is_movable contained
syntax keyword SVMFunction svm_value_state_is_null contained
syntax keyword SVMFunction svm_value_state_set_movable contained
syntax keyword SVMFunction svm_value_type_is_boolean contained
syntax keyword SVMFunction svm_value_type_is_integer contained
syntax keyword SVMFunction svm_value_type_is_interruption contained
syntax keyword SVMFunction svm_value_type_is_library contained
syntax keyword SVMFunction svm_value_type_is_plugin contained
syntax keyword SVMFunction svm_value_type_is_pluginentrypoint contained
syntax keyword SVMFunction svm_value_type_is_pointer contained
syntax keyword SVMFunction svm_value_type_is_string contained
syntax keyword SVMFunction svm_value_type_is_symbol contained
syntax keyword SVMFunction svm_variable_is_valid contained
syntax keyword SVMFunction svm_variable_scope_is_global contained
syntax keyword SVMFunction svm_variable_scope_is_local contained
syntax keyword SVMFunction svm_variable_scope_is_shared contained
syntax keyword SVMFunction svm_variable_type_is_accesscontrol contained
syntax keyword SVMFunction svm_variable_type_is_code contained
syntax keyword SVMFunction svm_variable_type_is_eventqueue contained
syntax keyword SVMFunction svm_variable_type_is_eventqueueaddress contained
syntax keyword SVMFunction svm_variable_type_is_kernel contained
syntax keyword SVMFunction svm_variable_type_is_lock contained
syntax keyword SVMFunction svm_variable_type_is_lockguardread contained
syntax keyword SVMFunction svm_variable_type_is_lockguardwrite contained
syntax keyword SVMFunction svm_variable_type_is_memoryzone contained
syntax keyword SVMFunction svm_variable_type_is_parameter contained
syntax keyword SVMFunction svm_variable_type_is_process contained
syntax keyword SVMFunction svm_variable_type_is_processlock contained
syntax keyword SVMFunction svm_variable_type_is_scheduler contained
syntax keyword SVMFunction svm_variable_type_is_structure contained
syntax keyword SVMFunction svm_variable_type_is_value contained
syntax keyword SVMFunction svm_code_new contained
syntax keyword SVMFunction svm_code_new__raw contained
syntax keyword SVMFunction svm_code_new__string contained
syntax keyword SVMFunction svm_processor_get_currentcode contained
syntax keyword SVMFunction svm_value_library_get_code contained
syntax keyword SVMFunction svm_value_symbol_get_code contained
syntax keyword SVMFunction svm_type_compare contained
syntax keyword SVMFunction svm_value_compare contained
syntax keyword SVMFunction svm_debug_form_new contained
syntax keyword SVMFunction svm_event_queue_new contained
syntax keyword SVMFunction svm_event_address_new contained
syntax keyword SVMFunction svm_event_address_new_struct contained
syntax keyword SVMFunction svm_memory_zone_find_memory_zone contained
syntax keyword SVMFunction svm_parameter_marker_find contained
syntax keyword SVMFunction svm_parameter_marker_find__raw contained
syntax keyword SVMFunction svm_parameter_marker_find_closing contained
syntax keyword SVMFunction svm_parameter_marker_find_separator contained
syntax keyword SVMFunction svm_processor_returnstack_find_flag contained
syntax keyword SVMFunction svm_processor_returnstack_find_flag__raw contained
syntax keyword SVMFunction svm_processor_returnstack_find_flag__string contained
syntax keyword SVMFunction svm_value_interruption_get_internal contained
syntax keyword SVMFunction svm_value_interruption_get_kind contained
syntax keyword SVMFunction svm_kernel_get_current contained
syntax keyword SVMFunction svm_kernel_new_code contained
syntax keyword SVMFunction svm_kernel_new_symbol contained
syntax keyword SVMFunction svm_process_kernel_get_current contained
syntax keyword SVMFunction svm_kernel_get_state contained
syntax keyword SVMFunction svm_lock_new contained
syntax keyword SVMFunction svm_lock_readguard_new contained
syntax keyword SVMFunction svm_lock_writeguard_new contained
syntax keyword SVMFunction svm_memory_pointer_get_zone contained
syntax keyword SVMFunction svm_memory_zone_copy contained
syntax keyword SVMFunction svm_memory_zone_new contained
syntax keyword SVMFunction svm_parameter_keyword_new contained
syntax keyword SVMFunction svm_parameter_keyword_new__raw contained
syntax keyword SVMFunction svm_parameter_marker_new contained
syntax keyword SVMFunction svm_parameter_marker_new__raw contained
syntax keyword SVMFunction svm_parameter_structure_new contained
syntax keyword SVMFunction svm_parameter_value_new contained
syntax keyword SVMFunction svm_parameter_variable_new contained
syntax keyword SVMFunction svm_parameter_array_new contained
syntax keyword SVMFunction svm_kernel_get_process contained
syntax keyword SVMFunction svm_process_get_current contained
syntax keyword SVMFunction svm_process_new contained
syntax keyword SVMFunction svm_process_new__raw contained
syntax keyword SVMFunction svm_process_new__string contained
syntax keyword SVMFunction svm_process_new_code contained
syntax keyword SVMFunction svm_process_new_code__raw contained
syntax keyword SVMFunction svm_process_new_code__string contained
syntax keyword SVMFunction svm_process_new_symbol contained
syntax keyword SVMFunction svm_process_new_symbol__raw contained
syntax keyword SVMFunction svm_process_new_symbol__string contained
syntax keyword SVMFunction svm_process_ownership_lock contained
syntax keyword SVMFunction svm_process_ownership_lock_critical contained
syntax keyword SVMFunction svm_process_get_state contained
syntax keyword SVMFunction svm_scheduler_get contained
syntax keyword SVMFunction svm_scheduler_get_current contained
syntax keyword SVMFunction svm_code_get_size contained
syntax keyword SVMFunction svm_memory_zone_get_size contained
syntax keyword SVMFunction svm_processor_returnstack_get_size contained
syntax keyword SVMFunction svm_value_pointer_get_size contained
syntax keyword SVMFunction svm_plugin_has_function_details contained
syntax keyword SVMFunction svm_code_get_name contained
syntax keyword SVMFunction svm_code_get_source contained
syntax keyword SVMFunction svm_code_instruction_get_location contained
syntax keyword SVMFunction svm_code_instruction_get_text contained
syntax keyword SVMFunction svm_code_print contained
syntax keyword SVMFunction svm_function_get_prototype contained
syntax keyword SVMFunction svm_kernel_get_coredump contained
syntax keyword SVMFunction svm_kernel_print contained
syntax keyword SVMFunction svm_machine_config contained
syntax keyword SVMFunction svm_memory_zone_print contained
syntax keyword SVMFunction svm_parameter_keyword_get contained
syntax keyword SVMFunction svm_parameter_marker_get contained
syntax keyword SVMFunction svm_plugin_print contained
syntax keyword SVMFunction svm_process_get_coredump contained
syntax keyword SVMFunction svm_process_get_name contained
syntax keyword SVMFunction svm_process_print contained
syntax keyword SVMFunction svm_process_sequencer_print contained
syntax keyword SVMFunction svm_scheduler_print contained
syntax keyword SVMFunction svm_string_join contained
syntax keyword SVMFunction svm_string_join__buffer contained
syntax keyword SVMFunction svm_string_join__raw contained
syntax keyword SVMFunction svm_string_new contained
syntax keyword SVMFunction svm_string_new__buffer contained
syntax keyword SVMFunction svm_string_new__raw contained
syntax keyword SVMFunction svm_type_print contained
syntax keyword SVMFunction svm_value_interruption_get_location contained
syntax keyword SVMFunction svm_value_interruption_get_message contained
syntax keyword SVMFunction svm_value_pluginentrypoint_get_entry contained
syntax keyword SVMFunction svm_value_pluginentrypoint_get_plugin contained
syntax keyword SVMFunction svm_value_print contained
syntax keyword SVMFunction svm_value_string_get contained
syntax keyword SVMFunction svm_value_symbol_get_location contained
syntax keyword SVMFunction svm_value_type_print contained
syntax keyword SVMFunction svm_event_address_get_struct contained
syntax keyword SVMFunction svm_parameter_structure_get contained
syntax keyword SVMFunction svm_structure_copy contained
syntax keyword SVMFunction svm_structure_new contained
syntax keyword SVMFunction svm_structure_new_null contained
syntax keyword SVMFunction svm_memory_address_get_type contained
syntax keyword SVMFunction svm_memory_zone_get_type contained
syntax keyword SVMFunction svm_type_copy contained
syntax keyword SVMFunction svm_type_new_external contained
syntax keyword SVMFunction svm_type_new_internal contained
syntax keyword SVMFunction svm_value_type_get contained
syntax keyword SVMFunction svm_type_get_internal contained
syntax keyword SVMFunction svm_memory_extract_address contained
syntax keyword SVMFunction svm_memory_read_address contained
syntax keyword SVMFunction svm_memory_read_address_type contained
syntax keyword SVMFunction svm_memory_read_address_type_external contained
syntax keyword SVMFunction svm_memory_read_address_type_internal contained
syntax keyword SVMFunction svm_parameter_value_get contained
syntax keyword SVMFunction svm_plugin_get_argument contained
syntax keyword SVMFunction svm_plugin_get_option contained
syntax keyword SVMFunction svm_value_copy contained
syntax keyword SVMFunction svm_debug_form_request contained
syntax keyword SVMFunction svm_memory_extract_pointer contained
syntax keyword SVMFunction svm_memory_extract_pointer__raw contained
syntax keyword SVMFunction svm_memory_read_pointer contained
syntax keyword SVMFunction svm_memory_read_pointer__raw contained
syntax keyword SVMFunction svm_memory_read_pointer_type contained
syntax keyword SVMFunction svm_memory_read_pointer_type__raw contained
syntax keyword SVMFunction svm_memory_read_pointer_type_external contained
syntax keyword SVMFunction svm_memory_read_pointer_type_external__raw contained
syntax keyword SVMFunction svm_memory_read_pointer_type_internal contained
syntax keyword SVMFunction svm_memory_read_pointer_type_internal__raw contained
syntax keyword SVMFunction svm_memory_read_pointer_zone contained
syntax keyword SVMFunction svm_memory_read_pointer_zone__raw contained
syntax keyword SVMFunction svm_plugin_get_arguments contained
syntax keyword SVMFunction svm_value_array_new contained
syntax keyword SVMFunction svm_value_automatic_new_null contained
syntax keyword SVMFunction svm_value_boolean_new contained
syntax keyword SVMFunction svm_value_boolean_new__raw contained
syntax keyword SVMFunction svm_value_boolean_new_null contained
syntax keyword SVMFunction svm_value_integer_new contained
syntax keyword SVMFunction svm_value_integer_new_null contained
syntax keyword SVMFunction svm_kernel_get_interruption contained
syntax keyword SVMFunction svm_process_get_interruption contained
syntax keyword SVMFunction svm_processor_get_currentinterruption contained
syntax keyword SVMFunction svm_value_interruption_new_external contained
syntax keyword SVMFunction svm_value_interruption_new_external__raw contained
syntax keyword SVMFunction svm_value_interruption_new_external__string contained
syntax keyword SVMFunction svm_value_interruption_new_internal contained
syntax keyword SVMFunction svm_value_interruption_new_internal__raw contained
syntax keyword SVMFunction svm_value_interruption_new_internal__string contained
syntax keyword SVMFunction svm_value_interruption_new_null contained
syntax keyword SVMFunction svm_machine_list_interruption contained
syntax keyword SVMFunction svm_processor_list_interruption contained
syntax keyword SVMFunction svm_value_library_new contained
syntax keyword SVMFunction svm_value_library_new_null contained
syntax keyword SVMFunction svm_value_plugin_new contained
syntax keyword SVMFunction svm_value_plugin_new_const contained
syntax keyword SVMFunction svm_value_plugin_new_const__raw contained
syntax keyword SVMFunction svm_value_plugin_new_const__string contained
syntax keyword SVMFunction svm_value_plugin_new_null contained
syntax keyword SVMFunction svm_process_get_scheduler contained
syntax keyword SVMFunction svm_process_get_sequencer contained
syntax keyword SVMFunction svm_structure_get_type contained
syntax keyword SVMFunction svm_type_get_external contained
syntax keyword SVMFunction svm_value_interruption_get_external contained
syntax keyword SVMFunction svm_value_plugin_get_type contained
syntax keyword SVMFunction svm_value_pluginentrypoint_new contained
syntax keyword SVMFunction svm_value_pluginentrypoint_new__raw contained
syntax keyword SVMFunction svm_value_pluginentrypoint_new__string contained
syntax keyword SVMFunction svm_value_pluginentrypoint_new_null contained
syntax keyword SVMFunction svm_value_pluginentrypoint_new_prefix contained
syntax keyword SVMFunction svm_value_plugin_compare_convert contained
syntax keyword SVMFunction svm_memory_alias_get_pointer contained
syntax keyword SVMFunction svm_memory_alias_get_pointer__raw contained
syntax keyword SVMFunction svm_memory_alias_get_pointer__string contained
syntax keyword SVMFunction svm_memory_allocate contained
syntax keyword SVMFunction svm_memory_allocate_address contained
syntax keyword SVMFunction svm_processor_get_currentpointer contained
syntax keyword SVMFunction svm_value_pointer_new contained
syntax keyword SVMFunction svm_value_pointer_new__raw contained
syntax keyword SVMFunction svm_value_pointer_new_null contained
syntax keyword SVMFunction svm_memory_pointer_list_accessible contained
syntax keyword SVMFunction svm_value_string_new contained
syntax keyword SVMFunction svm_value_string_new__buffer contained
syntax keyword SVMFunction svm_value_string_new__raw contained
syntax keyword SVMFunction svm_value_string_new_null contained
syntax keyword SVMFunction svm_code_label_list contained
syntax keyword SVMFunction svm_code_symbol_list contained
syntax keyword SVMFunction svm_memory_pointer_expand_alias contained
syntax keyword SVMFunction svm_memory_pointer_list_alias contained
syntax keyword SVMFunction svm_processor_list_flag contained
syntax keyword SVMFunction svm_code_symbol_get_address contained
syntax keyword SVMFunction svm_code_symbol_get_address__raw contained
syntax keyword SVMFunction svm_code_symbol_get_address__string contained
syntax keyword SVMFunction svm_processor_get_currentinstruction contained
syntax keyword SVMFunction svm_processor_get_nextinstruction contained
syntax keyword SVMFunction svm_processor_interruptionhandler_get contained
syntax keyword SVMFunction svm_value_symbol_new contained
syntax keyword SVMFunction svm_value_symbol_new_null contained
syntax keyword SVMFunction svm_code_compile contained
syntax keyword SVMFunction svm_code_compile__raw contained
syntax keyword SVMFunction svm_code_compile__string contained
syntax keyword SVMFunction svm_function_call contained
syntax keyword SVMFunction svm_parameter_variable_get contained
syntax keyword SVMFunction svm_variable_array_new contained
syntax keyword SVMFunction svm_api_get_signature contained
syntax keyword SVMFunction svm_value_integer_get contained
syntax keyword SVMFunction svm_accesscontrol_get_instructions contained
syntax keyword SVMFunction svm_accesscontrol_get_memory contained
syntax keyword SVMFunction svm_accesscontrol_set_instructions contained
syntax keyword SVMFunction svm_accesscontrol_set_memory contained
syntax keyword SVMFunction svm_debug_break contained
syntax keyword SVMFunction svm_debug_break__raw contained
syntax keyword SVMFunction svm_debug_break__string contained
syntax keyword SVMFunction svm_debug_breakpoint_add_break contained
syntax keyword SVMFunction svm_debug_breakpoint_add_interruption contained
syntax keyword SVMFunction svm_debug_breakpoint_add_memoryaccess contained
syntax keyword SVMFunction svm_debug_breakpoint_add_memoryfree contained
syntax keyword SVMFunction svm_debug_breakpoint_add_memoryread contained
syntax keyword SVMFunction svm_debug_breakpoint_add_memorywrite contained
syntax keyword SVMFunction svm_debug_breakpoint_remove_break contained
syntax keyword SVMFunction svm_debug_breakpoint_remove_interruption contained
syntax keyword SVMFunction svm_debug_breakpoint_remove_memoryaccess contained
syntax keyword SVMFunction svm_debug_breakpoint_remove_memoryfree contained
syntax keyword SVMFunction svm_debug_breakpoint_remove_memoryread contained
syntax keyword SVMFunction svm_debug_breakpoint_remove_memorywrite contained
syntax keyword SVMFunction svm_debug_form_append_checkbox contained
syntax keyword SVMFunction svm_debug_form_append_checkbox__raw contained
syntax keyword SVMFunction svm_debug_form_append_integer contained
syntax keyword SVMFunction svm_debug_form_append_integer__raw contained
syntax keyword SVMFunction svm_debug_form_append_selection contained
syntax keyword SVMFunction svm_debug_form_append_string contained
syntax keyword SVMFunction svm_debug_form_append_string__raw contained
syntax keyword SVMFunction svm_debug_form_append_string__string contained
syntax keyword SVMFunction svm_debug_form_append_text contained
syntax keyword SVMFunction svm_debug_notify contained
syntax keyword SVMFunction svm_debug_notify__raw contained
syntax keyword SVMFunction svm_debug_notify__string contained
syntax keyword SVMFunction svm_debug_synchronise contained
syntax keyword SVMFunction svm_event_queue_broadcast contained
syntax keyword SVMFunction svm_event_queue_join contained
syntax keyword SVMFunction svm_event_queue_leave contained
syntax keyword SVMFunction svm_event_queue_push contained
syntax keyword SVMFunction svm_kernel_set_accesscontrol contained
syntax keyword SVMFunction svm_kernel_suspend contained
syntax keyword SVMFunction svm_kernel_swap_memory contained
syntax keyword SVMFunction svm_kernel_terminate contained
syntax keyword SVMFunction svm_machine_shutdown contained
syntax keyword SVMFunction svm_machine_shutdown__raw contained
syntax keyword SVMFunction svm_machine_trace contained
syntax keyword SVMFunction svm_machine_trace__raw contained
syntax keyword SVMFunction svm_machine_trace__string contained
syntax keyword SVMFunction svm_memory_add_alias contained
syntax keyword SVMFunction svm_memory_add_alias__raw contained
syntax keyword SVMFunction svm_memory_add_alias__string contained
syntax keyword SVMFunction svm_memory_address_set_type contained
syntax keyword SVMFunction svm_memory_address_shift contained
syntax keyword SVMFunction svm_memory_address_shift__raw contained
syntax keyword SVMFunction svm_memory_copy contained
syntax keyword SVMFunction svm_memory_free contained
syntax keyword SVMFunction svm_memory_move contained
syntax keyword SVMFunction svm_memory_pointer_set_zone contained
syntax keyword SVMFunction svm_memory_remove_alias contained
syntax keyword SVMFunction svm_memory_remove_alias__raw contained
syntax keyword SVMFunction svm_memory_remove_alias__string contained
syntax keyword SVMFunction svm_memory_scope_set_global contained
syntax keyword SVMFunction svm_memory_scope_set_global_alias contained
syntax keyword SVMFunction svm_memory_scope_set_global_alias__raw contained
syntax keyword SVMFunction svm_memory_scope_set_global_alias__string contained
syntax keyword SVMFunction svm_memory_scope_set_local contained
syntax keyword SVMFunction svm_memory_scope_set_local_alias contained
syntax keyword SVMFunction svm_memory_scope_set_local_alias__raw contained
syntax keyword SVMFunction svm_memory_scope_set_local_alias__string contained
syntax keyword SVMFunction svm_memory_share contained
syntax keyword SVMFunction svm_memory_synchronisation_disable contained
syntax keyword SVMFunction svm_memory_synchronisation_enable contained
syntax keyword SVMFunction svm_memory_translate contained
syntax keyword SVMFunction svm_memory_write_address contained
syntax keyword SVMFunction svm_memory_write_pointer contained
syntax keyword SVMFunction svm_memory_write_pointer__raw contained
syntax keyword SVMFunction svm_memory_zone_append contained
syntax keyword SVMFunction svm_memory_zone_append__raw contained
syntax keyword SVMFunction svm_memory_zone_append_external contained
syntax keyword SVMFunction svm_memory_zone_append_external__raw contained
syntax keyword SVMFunction svm_memory_zone_append_internal contained
syntax keyword SVMFunction svm_memory_zone_append_internal__raw contained
syntax keyword SVMFunction svm_memory_zone_append_memory_zone contained
syntax keyword SVMFunction svm_memory_zone_insert_memory_zone contained
syntax keyword SVMFunction svm_memory_zone_remove_memory_zone contained
syntax keyword SVMFunction svm_memory_zone_replace_memory_zone contained
syntax keyword SVMFunction svm_plugin_configure contained
syntax keyword SVMFunction svm_process_interrupt contained
syntax keyword SVMFunction svm_process_interruptionnotification_disable contained
syntax keyword SVMFunction svm_process_interruptionnotification_enable contained
syntax keyword SVMFunction svm_process_interruptionnotification_send contained
syntax keyword SVMFunction svm_process_interruptionnotification_wait contained
syntax keyword SVMFunction svm_process_pause contained
syntax keyword SVMFunction svm_process_resume contained
syntax keyword SVMFunction svm_process_run contained
syntax keyword SVMFunction svm_process_run__raw contained
syntax keyword SVMFunction svm_process_suspend contained
syntax keyword SVMFunction svm_process_terminate contained
syntax keyword SVMFunction svm_processor_add_interruption contained
syntax keyword SVMFunction svm_processor_call_global contained
syntax keyword SVMFunction svm_processor_call_identical contained
syntax keyword SVMFunction svm_processor_call_local contained
syntax keyword SVMFunction svm_processor_clear_interruption contained
syntax keyword SVMFunction svm_processor_current_raise_error contained
syntax keyword SVMFunction svm_processor_current_raise_error_external__raw contained
syntax keyword SVMFunction svm_processor_current_raise_error_internal__raw contained
syntax keyword SVMFunction svm_processor_current_shutdown contained
syntax keyword SVMFunction svm_processor_current_sleep contained
syntax keyword SVMFunction svm_processor_current_sleep__raw contained
syntax keyword SVMFunction svm_processor_hold_interruption contained
syntax keyword SVMFunction svm_processor_instructionoverride_reset_global contained
syntax keyword SVMFunction svm_processor_instructionoverride_reset_local contained
syntax keyword SVMFunction svm_processor_instructionoverride_set_global contained
syntax keyword SVMFunction svm_processor_instructionoverride_set_local contained
syntax keyword SVMFunction svm_processor_interruptionhandler_reset contained
syntax keyword SVMFunction svm_processor_interruptionhandler_set_global contained
syntax keyword SVMFunction svm_processor_interruptionhandler_set_local contained
syntax keyword SVMFunction svm_processor_jump_global contained
syntax keyword SVMFunction svm_processor_jump_local contained
syntax keyword SVMFunction svm_processor_release_interruption contained
syntax keyword SVMFunction svm_processor_reset_flag contained
syntax keyword SVMFunction svm_processor_reset_flag__raw contained
syntax keyword SVMFunction svm_processor_reset_flag__string contained
syntax keyword SVMFunction svm_processor_return contained
syntax keyword SVMFunction svm_processor_returnstack_move_level contained
syntax keyword SVMFunction svm_processor_returnstack_swap_level contained
syntax keyword SVMFunction svm_processor_set_currentinterruption contained
syntax keyword SVMFunction svm_processor_set_currentpointer contained
syntax keyword SVMFunction svm_processor_set_flag contained
syntax keyword SVMFunction svm_processor_set_flag__raw contained
syntax keyword SVMFunction svm_processor_set_flag__string contained
syntax keyword SVMFunction svm_scheduler_notify contained
syntax keyword SVMFunction svm_scheduler_notify__raw contained
syntax keyword SVMFunction svm_value_boolean_set contained
syntax keyword SVMFunction svm_value_boolean_set__raw contained
syntax keyword SVMFunction svm_value_integer_set contained
syntax keyword SVMFunction svm_value_interruption_set contained
syntax keyword SVMFunction svm_value_interruption_set_external contained
syntax keyword SVMFunction svm_value_interruption_set_external__raw contained
syntax keyword SVMFunction svm_value_interruption_set_external__string contained
syntax keyword SVMFunction svm_value_interruption_set_internal contained
syntax keyword SVMFunction svm_value_interruption_set_internal__raw contained
syntax keyword SVMFunction svm_value_interruption_set_internal__string contained
syntax keyword SVMFunction svm_value_library_set contained
syntax keyword SVMFunction svm_value_library_set_code contained
syntax keyword SVMFunction svm_value_plugin_set contained
syntax keyword SVMFunction svm_value_plugin_set_internal contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_entry contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_entry__raw contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_entry__string contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_plugin contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_plugin__raw contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_plugin__string contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_pluginentry contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_pluginentry__raw contained
syntax keyword SVMFunction svm_value_pluginentrypoint_set_pluginentry__string contained
syntax keyword SVMFunction svm_value_pointer_set contained
syntax keyword SVMFunction svm_value_pointer_set_address contained
syntax keyword SVMFunction svm_value_pointer_set_address__raw contained
syntax keyword SVMFunction svm_value_pointer_set_addresssize contained
syntax keyword SVMFunction svm_value_pointer_set_addresssize__raw contained
syntax keyword SVMFunction svm_value_pointer_set_size contained
syntax keyword SVMFunction svm_value_pointer_set_size__raw contained
syntax keyword SVMFunction svm_value_string_set contained
syntax keyword SVMFunction svm_value_string_set__buffer contained
syntax keyword SVMFunction svm_value_string_set__raw contained
syntax keyword SVMFunction svm_value_symbol_set contained
syntax keyword SVMFunction svm_value_symbol_set_address contained
syntax keyword SVMFunction svm_value_symbol_set_code contained
syntax keyword SVMFunction svm_value_symbol_set_codeaddress contained
syntax keyword SVMFunction svm_variable_delete contained
syntax keyword SVMFunction svm_variable_scope_reset_shared contained
syntax keyword SVMFunction svm_variable_scope_set_global contained
syntax keyword SVMFunction svm_variable_scope_set_local contained
syntax keyword SVMFunction svm_variable_scope_set_shared contained
syntax keyword SVMFunction svm_process_sequencer_get_internal contained
syntax keyword SVMFunction svm_scheduler_get_internal contained
syntax keyword SVMFunction svm_structure_get_internal contained
syntax keyword SVMFunction svm_value_plugin_get_internal contained
syntax keyword SVMType SVM_Kernel_State contained
syntax keyword SVMType SVM_AccessControl contained
syntax keyword SVMType SVM_Code contained
syntax keyword SVMType SVM_Debug_Form contained
syntax keyword SVMType SVM_Event_Queue contained
syntax keyword SVMType SVM_Event_Queue_Address contained
syntax keyword SVMType SVM_Kernel contained
syntax keyword SVMType SVM_Lock contained
syntax keyword SVMType SVM_LockGuard_Read contained
syntax keyword SVMType SVM_LockGuard_Write contained
syntax keyword SVMType SVM_Memory_Zone contained
syntax keyword SVMType SVM_Parameter contained
syntax keyword SVMType SVM_Process contained
syntax keyword SVMType SVM_Process_Lock contained
syntax keyword SVMType SVM_Scheduler contained
syntax keyword SVMType SVM_Structure contained
syntax keyword SVMType SVM_Type contained
syntax keyword SVMType SVM_Value contained
syntax keyword SVMType SVM_Value_Automatic contained
syntax keyword SVMType SVM_Value_Boolean contained
syntax keyword SVMType SVM_Value_Integer contained
syntax keyword SVMType SVM_Value_Interruption contained
syntax keyword SVMType SVM_Value_Library contained
syntax keyword SVMType SVM_Value_Plugin contained
syntax keyword SVMType SVM_Value_PluginEntryPoint contained
syntax keyword SVMType SVM_Value_Pointer contained
syntax keyword SVMType SVM_Value_String contained
syntax keyword SVMType SVM_Value_Symbol contained
syntax keyword SVMType SVM_Variable contained
syntax keyword SVMType SVM_Type_Internal contained
syntax keyword SVMConstant AUTOMATIC contained
syntax keyword SVMConstant INTEGER contained
syntax keyword SVMConstant STRING contained
syntax keyword SVMConstant BOOLEAN contained
syntax keyword SVMConstant POINTER contained
syntax keyword SVMConstant LIBRARY contained
syntax keyword SVMConstant SYMBOL contained
syntax keyword SVMConstant PLUGIN_ENTRY_POINT contained
syntax keyword SVMConstant INTERRUPTION contained
syntax keyword SVMType SVM_Interruption_Internal contained
syntax keyword SVMConstant CLONE contained
syntax keyword SVMConstant DEVICE contained
syntax keyword SVMConstant FAILURE contained
syntax keyword SVMConstant FIRST contained
syntax keyword SVMConstant MEMORY contained
syntax keyword SVMConstant NUMERIC contained
syntax keyword SVMConstant PROCESSOR contained
syntax keyword SVMConstant SECOND contained
syntax keyword SVMConstant SECURITY contained
syntax keyword SVMConstant TERMINATE contained
syntax keyword SVMConstant TERMINAL contained
syntax keyword SVMConstant GENERIC contained
syntax keyword SVMType SVM_Value_Plugin_Comparison contained
syntax keyword SVMConstant EQUIVALENCE_EQUAL contained
syntax keyword SVMConstant EQUIVALENCE_DIFFERENT contained
syntax keyword SVMConstant ORDER_EQUAL contained
syntax keyword SVMConstant ORDER_INFERIOR contained
syntax keyword SVMConstant ORDER_SUPERIOR contained
syntax keyword SVMConstant ORDER_UNCOMPARABLE contained
syntax keyword SVMConstant ORDER_TOTAL contained
syntax keyword SVMConstant ORDER_PARTIAL contained
syntax keyword SVMConstant COMPARISON_STRONG contained
syntax keyword SVMConstant COMPARISON_WEAK contained
syntax keyword SVMType SVM_Boolean contained
syntax keyword SVMConstant FALSE contained
syntax keyword SVMConstant TRUE contained
syntax keyword SVMType SVM_Object_Level contained
syntax keyword SVMConstant LOCAL contained
syntax keyword SVMConstant CASCADE contained
syntax keyword SVMConstant GLOBAL contained
syntax keyword SVMType SVM_Notification_Type contained
syntax keyword SVMConstant NOTIFICATION contained
syntax keyword SVMConstant TIMER contained
syntax keyword SVMType SVM_Process_State contained
syntax keyword SVMConstant RUNNING contained
syntax keyword SVMConstant SUSPENDED contained
syntax keyword SVMConstant WAITING contained
syntax keyword SVMConstant CONTINUE contained
syntax keyword SVMConstant LOCKED contained
syntax keyword SVMConstant DEBUG contained
syntax keyword SVMConstant ZOMBIE contained
syntax keyword SVMConstant INTERRUPTED contained
syntax keyword SVMConstant ERROR contained
syntax keyword SVMType SVM_Interruption_Kind contained
syntax keyword SVMConstant SOFTWARE contained
syntax keyword SVMConstant HARDWARE contained
syntax keyword SVMType SVM_Status_Boolean contained
syntax keyword SVMType SVM_Comparison_Result contained
syntax keyword SVMType SVM_String contained
syntax keyword SVMType SVM_Address contained
syntax keyword SVMType SVM_Index contained
syntax keyword SVMType SVM_Size contained
